#!/usr/bin/php
<?php

#Habilita a exibição de erros (strict)
//error_reporting(E_ALL);

/*******************************************************************************
* Header
********************************************************************************

AUTOR: 
CRIADO EM: 

REVISÕES:
--------------------------------------------------------------
<versão> <Data da Revisão>, <autor da revisao>
    - <Descrição das modificações>

********************************************************************************/

require_once("/usr/local/opmon/libexec/opservices/lib/php/Nagios/Plugin.php");

define("VERSION","1.0");
define("START_INTERVAL_DEFAULT",0);
define("END_INTERVAL_DEFAULT",100);

$np = null;

/*******************************************************************************
* Exibi o manual do software
********************************************************************************/

function getGuideLine() {

    print <<<EOF

------------------------------------------
Manual de exemplo.
------------------------------------------

Descrição do plugin:
    Este plugin monitora o valor gerado randomicamente pelo sistema.

Instalação:
    Passos para instalação

Dependências:
    <Listar todas>
    <Dependência>
    <Instalação>

Funcionamento:
    O plugin recebe do usuário um intervalo no qual deve gerar um numero de forma
    randômica e caso o valor seja maior que o threshold ele alarma.

Exemplos de execução e retorno do comando:
    <Listar todos possíveis>

    ./check_example -s 1 -e 15
    OK: Numero gerado 10

    ./check_example -s 1 -e 15 --perfdata
    OK: Numero gerado 15 | num=15;;;;

    ./check_example -s 1 -e 15 -w 10 -c 11
    CRITICAL: Numero gerado 15 | num=15;10;11;;

    ./check_example -s 1 -e 15 -w 10 -c 20
    WARNING: Numero gerado 15 | num=15;10;20;;

    ./check_example -s 20 -e 15
    UNKNOWN: Intervalo invalido


EOF;

    exit (OK);

}

/*******************************************************************************
* Seta os atributos da variável global $np
********************************************************************************/

function setNagios() {

    # Constructor
    global $np;

    $np = new Nagios_Plugin(
        array (
            'version' => VERSION . " [www.opservices.com.br/suporte]",
            'blurb' => "Developed by:\n\tOpServices\n"
                . "Author: \n\tDaniel Ortiz - daniel.ortiz\@opservices.com\n",
            'usage' => "Usage:\n\t%s -s <start_number> -e <end_number>\n"
                . " \t [-w <warning>] [-c <critical>]",

        )
    );
    //            option     ,         help             ,required
    $np->add_arg("start|s=i", "Initial interval number", true);
    $np->add_arg("end|e=i", "End interval number", true);
    $np->add_arg("warning|w=i", "Warning value");
    $np->add_arg("critical|c=i", "Critical value");
    $np->add_arg("perfdata", "Show perfdata");
    $np->add_arg("man","Show guideline");

    $np->getopts();

    if (!isset($np->opts['start'])) $np->opts['start'] = START_INTERVAL_DEFAULT;

    if (!isset($np->opts['end'])) $np->opts['end'] = END_INTERVAL_DEFAULT;

    if ( isset($np->opts['warning']) and isset($np->opts['critical']) )
        $np->set_thresholds( $np->opts['warning'], $np->opts['critical'], 0);

}

/*******************************************************************************
* Gera um numero randômico entre dois valores passado por parâmetro.
* O numero gerado segue o seguinte padrão: x >= start e x <= end
* @link http://php.net/manual/pt_BR/function.rand.php
* @param $start Valor inicial do intervalo
* @param $end Valor final do intervalo
* @return $randomNumber Numero randômico gerado.
********************************************************************************/

function getRandomNumber($start, $end) {

    global $np;

    if ($start > $end)
        $np->nagios_die("Intervalo inválido");

    $randomNumber = rand( $start, $end );

    if ($np->opts['verbose']) {
		print "Debug: Start interval $start\n";
		print "Debug: End interval $end\n";
	    print "Debug: Numero Gerado $randomNumber\n";
	}

    return $randomNumber;
}

/*******************************************************************************
* Rotina principal do programa
********************************************************************************/

function main() {

    setNagios();

    global $np;

    if (isset($np->opts['man'])) getGuideLine();

    $randomNumber = getRandomNumber($np->opts['start'], $np->opts['end']);

    if ( isset($np->opts['perfdata'])
        or (isset($np->opts['warning']) and isset($np->opts['critical'])) )
        //                 label, value        , uom, threshold object
        $np->add_perfdata( "num", $randomNumber, "", $np->threshold() );

    $np->nagios_exit(
        $np->check_threshold($randomNumber),
        "Numero gerado $randomNumber"
    );
}

main();

/* vim: set smartindent tabstop=4 shiftwidth=4 softtabstop=4 expandtab[ENTER] */

?>
